Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/prusa3d/PrusaSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlessandro Ranellucci <aar@cpan.org>2011-11-26 18:21:15 +0400
committerAlessandro Ranellucci <aar@cpan.org>2011-11-26 18:21:15 +0400
commit951778439ac86c4b8f1c27c3e04efc0f65705ab9 (patch)
treed977536653b41922079ccf82580ddc6e57baad94 /lib/Slic3r/Surface.pm
parentafd8e0a1bdc92471deb2f85d12ac06475986939c (diff)
Bugfix: recent changes broke the "infill every layers" option which didn't alternate infill direction correctly. #70
Diffstat (limited to 'lib/Slic3r/Surface.pm')
-rw-r--r--lib/Slic3r/Surface.pm5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/Slic3r/Surface.pm b/lib/Slic3r/Surface.pm
index 811945371..ef5d5c333 100644
--- a/lib/Slic3r/Surface.pm
+++ b/lib/Slic3r/Surface.pm
@@ -49,7 +49,7 @@ sub cast_from_expolygon {
);
}
# static method to group surfaces having same surface_type and bridge_angle
sub group {
my $class = shift;
my $params = ref $_[0] eq 'HASH' ? shift(@_) : {};
@@ -57,7 +57,8 @@ sub group {
my $unique_type = sub {
($params->{merge_solid} && $_[0]->surface_type =~ /top|bottom|solid/
- ? 'solid' : $_[0]->surface_type) . "_" . ($_[0]->bridge_angle || '');
+ ? 'solid' : $_[0]->surface_type) . "_" . ($_[0]->bridge_angle || '')
+ . "_" . $_[0]->depth_layers;
};
my @unique_types = ();
foreach my $surface (@surfaces) {
@@ -49,7 +49,7 @@ sub cast_from_expolygon {
);
}
-# static method to group surfaces having same surface_type and bridge_angle
+# static method to group surfaces having same surface_type, bridge_angle and depth_layers
sub group {
my $class = shift;